@@ -18,9 +18,7 @@
 #include <inttypes.h>
 
 #include <php.h>
-#include <zend_smart_str.h>
 #include <ext/date/php_date.h>
-#include <ext/standard/php_var.h>
 #include <Zend/zend_interfaces.h>
 
 #include "php_phongo.h"
@@ -123,16 +121,6 @@ static bool php_phongo_utcdatetime_init_from_object(php_phongo_utcdatetime_t* in
 	return false;
 }
 
-static bool php_phongo_utcdatetime_init_from_double(php_phongo_utcdatetime_t* intern, double milliseconds)
-{
-	char tmp[24];
-	int  tmp_len;
-
-	tmp_len = snprintf(tmp, sizeof(tmp), "%.0f", milliseconds > 0 ? floor(milliseconds) : ceil(milliseconds));
-
-	return php_phongo_utcdatetime_init_from_string(intern, tmp, tmp_len);
-}
-
 static HashTable* php_phongo_utcdatetime_get_properties_hash(zend_object* object, bool is_temp)
 {
 	php_phongo_utcdatetime_t* intern;
@@ -216,21 +204,9 @@ static PHP_METHOD(MongoDB_BSON_UTCDateTime, __construct)
 		case IS_LONG:
 			php_phongo_utcdatetime_init(intern, Z_LVAL_P(milliseconds));
 			return;
-
-		case IS_DOUBLE:
-			php_error_docref(NULL, E_DEPRECATED, "Creating a %s instance with a float is deprecated and will be removed in ext-mongodb 2.0", ZSTR_VAL(php_phongo_utcdatetime_ce->name));
-
-			php_phongo_utcdatetime_init_from_double(intern, Z_DVAL_P(milliseconds));
-			return;
-
-		case IS_STRING:
-			php_error_docref(NULL, E_DEPRECATED, "Creating a %s instance with a string is deprecated and will be removed in ext-mongodb 2.0", ZSTR_VAL(php_phongo_utcdatetime_ce->name));
-
-			php_phongo_utcdatetime_init_from_string(intern, Z_STRVAL_P(milliseconds), Z_STRLEN_P(milliseconds));
-			return;
 	}
 
-	phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT, "Expected integer or string, %s given", zend_zval_type_name(milliseconds));
+	phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT, "Expected integer or object, %s given", zend_zval_type_name(milliseconds));
 }
 
 static PHP_METHOD(MongoDB_BSON_UTCDateTime, __set_state)
@@ -298,59 +274,6 @@ static PHP_METHOD(MongoDB_BSON_UTCDateTime, jsonSerialize)
 	}
 }
 
-static PHP_METHOD(MongoDB_BSON_UTCDateTime, serialize)
-{
-	php_phongo_utcdatetime_t* intern;
-	zval                      retval;
-	php_serialize_data_t      var_hash;
-	smart_str                 buf = { 0 };
-
-	intern = Z_UTCDATETIME_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_NONE();
-
-	array_init_size(&retval, 1);
-	ADD_ASSOC_INT64_AS_STRING(&retval, "milliseconds", intern->milliseconds);
-
-	PHP_VAR_SERIALIZE_INIT(var_hash);
-	php_var_serialize(&buf, &retval, &var_hash);
-	smart_str_0(&buf);
-	PHP_VAR_SERIALIZE_DESTROY(var_hash);
-
-	PHONGO_RETVAL_SMART_STR(buf);
-
-	smart_str_free(&buf);
-	zval_ptr_dtor(&retval);
-}
-
-static PHP_METHOD(MongoDB_BSON_UTCDateTime, unserialize)
-{
-	php_phongo_utcdatetime_t* intern;
-	char*                     serialized;
-	size_t                    serialized_len;
-	zval                      props;
-	php_unserialize_data_t    var_hash;
-
-	intern = Z_UTCDATETIME_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_START(1, 1)
-	Z_PARAM_STRING(serialized, serialized_len)
-	PHONGO_PARSE_PARAMETERS_END();
-
-	PHP_VAR_UNSERIALIZE_INIT(var_hash);
-	if (!php_var_unserialize(&props, (const unsigned char**) &serialized, (unsigned char*) serialized + serialized_len, &var_hash)) {
-		zval_ptr_dtor(&props);
-		phongo_throw_exception(PHONGO_ERROR_UNEXPECTED_VALUE, "%s unserialization failed", ZSTR_VAL(php_phongo_utcdatetime_ce->name));
-
-		PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-		return;
-	}
-	PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-
-	php_phongo_utcdatetime_init_from_hash(intern, HASH_OF(&props));
-	zval_ptr_dtor(&props);
-}
-
 static PHP_METHOD(MongoDB_BSON_UTCDateTime, __serialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
@@ -442,7 +365,7 @@ static HashTable* php_phongo_utcdatetime_get_properties(zend_object* object)
 
 void php_phongo_utcdatetime_init_ce(INIT_FUNC_ARGS)
 {
-	php_phongo_utcdatetime_ce                = register_class_MongoDB_BSON_UTCDateTime(php_phongo_utcdatetime_interface_ce, php_phongo_json_serializable_ce, php_phongo_type_ce, zend_ce_serializable, zend_ce_stringable);
+	php_phongo_utcdatetime_ce                = register_class_MongoDB_BSON_UTCDateTime(php_phongo_utcdatetime_interface_ce, php_phongo_json_serializable_ce, php_phongo_type_ce, zend_ce_stringable);
 	php_phongo_utcdatetime_ce->create_object = php_phongo_utcdatetime_create_object;
 
 	memcpy(&php_phongo_handler_utcdatetime, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
