@@ -141,13 +141,13 @@ static zend_object* php_phongo_command_create_object(zend_class_entry* class_typ
 	return &intern->std;
 }
 
-static HashTable* php_phongo_command_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_command_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_command_t* intern;
 	zval                  retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern   = Z_OBJ_COMMAND(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_COMMAND(object);
 
 	array_init_size(&retval, 1);
 
@@ -172,7 +172,6 @@ void php_phongo_command_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_command_ce                = register_class_MongoDB_Driver_Command();
 	php_phongo_command_ce->create_object = php_phongo_command_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_command_ce);
 
 	memcpy(&php_phongo_handler_command, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_command.get_debug_info = php_phongo_command_get_debug_info;
