@@ -90,12 +90,12 @@ static zend_object* php_phongo_topologychangedevent_create_object(zend_class_ent
 	return &intern->std;
 }
 
-static HashTable* php_phongo_topologychangedevent_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_topologychangedevent_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_topologychangedevent_t* intern;
 	zval                               retval = ZVAL_STATIC_INIT;
 
-	intern   = Z_OBJ_TOPOLOGYCHANGEDEVENT(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_TOPOLOGYCHANGEDEVENT(object);
 	*is_temp = 1;
 	array_init_size(&retval, 3);
 
@@ -130,7 +130,6 @@ void php_phongo_topologychangedevent_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_topologychangedevent_ce                = register_class_MongoDB_Driver_Monitoring_TopologyChangedEvent();
 	php_phongo_topologychangedevent_ce->create_object = php_phongo_topologychangedevent_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_topologychangedevent_ce);
 
 	memcpy(&php_phongo_handler_topologychangedevent, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_topologychangedevent.get_debug_info = php_phongo_topologychangedevent_get_debug_info;
