@@ -1,7 +1,7 @@
 /* +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2013 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -25,16 +25,6 @@
 #include "zend_hash.h"
 #include "zend_list.h"
 
-#ifdef ZEND_ENGINE_3
-# define PAA_LENGTH_ADJ(l) (l)
-# define PAA_SYM_EXISTS zend_symtable_str_exists
-# define PAA_SYM_DEL    zend_symtable_str_del
-#else
-# define PAA_LENGTH_ADJ(l) (l+1)
-# define PAA_SYM_EXISTS zend_symtable_exists
-# define PAA_SYM_DEL    zend_symtable_del
-#endif
-
 /**
  * All APIs in this file follow a general format:
  *
@@ -72,28 +62,22 @@
  * zend_bool php_array_existsc(zval *zarr, const char *litstr)
  * zend_bool php_array_existsl(zval *zarr, const char *key, int key_len)
  * zend_bool php_array_existsl_safe(zval *zarr, const char *key, int key_len)
- * zend_bool php_array_existsn(zval *zarr, long idx)
+ * zend_bool php_array_existsn(zval *zarr, unsigned long idx)
  * zend_bool php_array_existsz(zval *zarr, zval *key)
  */
 static inline
 zend_bool php_array_exists(zval *zarr, const char *key) {
-	return PAA_SYM_EXISTS(Z_ARRVAL_P(zarr), key, PAA_LENGTH_ADJ(strlen(key)));
+	return zend_symtable_str_exists(Z_ARRVAL_P(zarr), key, strlen(key));
 }
 #define php_array_existsc(zarr, litstr) \
-	PAA_SYM_EXISTS(Z_ARRVAL_P(zarr), litstr, PAA_LENGTH_ADJ(sizeof(litstr) - 1))
+	zend_symtable_str_exists(Z_ARRVAL_P(zarr), litstr, sizeof(litstr) - 1)
 #define php_array_existsl(zarr, key, len) \
-	PAA_SYM_EXISTS(Z_ARRVAL_P(zarr), key, PAA_LENGTH_ADJ(len))
+	zend_symtable_str_exists(Z_ARRVAL_P(zarr), key, len)
 static inline
 zend_bool php_array_existsl_safe(zval *zarr, const char *key, int key_len) {
-#ifdef ZEND_ENGINE_3
 	zend_string *keystr = zend_string_init(key, key_len, 0);
 	zend_bool ret = zend_symtable_exists(Z_ARRVAL_P(zarr), keystr);
 	zend_string_release(keystr);
-#else
-	char *k = estrndup(key, key_len);
-	zend_bool ret = zend_symtable_exists(Z_ARRVAL_P(zarr), k, key_len + 1);
-	efree(k);
-#endif
 	return ret;
 }
 #define php_array_existsn(zarr, idx) \
@@ -103,14 +87,10 @@ zend_bool php_array_existsz(zval *zarr, zval *key) {
 	switch (Z_TYPE_P(key)) {
 		case IS_NULL:
 			return php_array_existsc(zarr, "");
-#ifdef ZEND_ENGINE_3
 		case IS_FALSE:
 			return zend_hash_index_exists(Z_ARRVAL_P(zarr), 0);
 		case IS_TRUE:
 			return zend_hash_index_exists(Z_ARRVAL_P(zarr), 1);
-#else
-		case IS_BOOL: /* fallthrough */
-#endif
 		case IS_LONG:
 			return zend_hash_index_exists(Z_ARRVAL_P(zarr), Z_LVAL_P(key));
 		case IS_DOUBLE:
@@ -153,7 +133,7 @@ zend_bool php_array_existsz(zval *zarr, zval *key) {
  *       NULL terminated string key of known length
  *   php_array_fetchl_safe_T(zval *zarr, const char *key, int key_len, ...)
  *       String key of known length, may not be NULL terminated
- *   php_array_fetchn_T(zval *zarr, long idx, ...)
+ *   php_array_fetchn_T(zval *zarr, unsigned long idx, ...)
  *       Numeric key
  *   php_array_fetchz_T(zval *zarr, zval *key, ...)
  *       zval* key
@@ -164,23 +144,13 @@ zend_bool php_array_existsz(zval *zarr, zval *key) {
  * zval *php_array_fetch(zval *zarr, const char *key)
  * zval *php_array_fetchl(zval *zarr, const char *key, int key_len)
  * zval *php_array_fetchl_safe(zval *zarr, const char *key, int key_len)
- * zval *php_array_fetchn(zval *zarr, long idx)
+ * zval *php_array_fetchn(zval *zarr, unsigned long idx)
  * zval *php_array_fetchc(zval *zarr, const char *litstr)
  * zval *php_array_fetchz(zval *zarr, zval *key)
  */
 static inline
 zval *php_array_fetchl(zval *zarr, const char *key, int key_len) {
-#ifdef ZEND_ENGINE_3
 	return zend_symtable_str_find(Z_ARRVAL_P(zarr), key, key_len);
-#else
-	zval **ppzval;
-	if (FAILURE == zend_symtable_find(Z_ARRVAL_P(zarr),
-                                          key, key_len + 1,
-                                          (void**)&ppzval)) {
-		return NULL;
-	}
-	return *ppzval;
-#endif
 }
 static inline
 zval *php_array_fetch(zval *zarr, const char *key) {
@@ -189,47 +159,27 @@ zval *php_array_fetch(zval *zarr, const char *key) {
 #define php_array_fetchc(zarr, litstr) php_array_fetchl(zarr, litstr, sizeof(litstr)-1)
 static inline
 zval *php_array_fetchl_safe(zval *zarr, const char *key, int key_len) {
-#ifdef ZEND_ENGINE_3
 	zend_string *keystr = zend_string_init(key, key_len, 0);
 	zval *ret = zend_symtable_find(Z_ARRVAL_P(zarr), keystr);
 	zend_string_release(keystr);
-#else
-	char *k = estrndup(key, key_len);
-	zval *ret = php_array_fetchl(zarr, k, key_len);
-	efree(k);
-#endif
 	return ret;
 }
 static inline
-zval *php_array_fetchn(zval *zarr, long idx) {
-#ifdef ZEND_ENGINE_3
+zval *php_array_fetchn(zval *zarr, zend_ulong idx) {
 	return zend_hash_index_find(Z_ARRVAL_P(zarr), idx);
-#else
-	zval **ppzval;
-	if (FAILURE == zend_hash_index_find(Z_ARRVAL_P(zarr),
-	                                    idx, (void**)&ppzval)) {
-		return NULL;
-	}
-	return *ppzval;
-#endif
 }
 static inline
 zval *php_array_fetchz(zval *zarr, zval *key) {
 	switch (Z_TYPE_P(key)) {
 		case IS_NULL:
-			return php_array_fetchn(zarr, 0);
-#ifdef ZEND_ENGINE_3
 		case IS_FALSE:
 			return php_array_fetchn(zarr, 0);
 		case IS_TRUE:
 			return php_array_fetchn(zarr, 1);
-#else
-		case IS_BOOL: /* fallthrough */
-#endif
 		case IS_LONG:
 			return php_array_fetchn(zarr, Z_LVAL_P(key));
 		case IS_DOUBLE:
-			return php_array_fetchn(zarr, (long)Z_DVAL_P(key));
+			return php_array_fetchn(zarr, (zend_ulong) Z_DVAL_P(key));
 		case IS_STRING:
 			return php_array_fetchl(zarr, Z_STRVAL_P(key), Z_STRLEN_P(key));
 		default:
@@ -237,24 +187,60 @@ zval *php_array_fetchz(zval *zarr, zval *key) {
 	}
 }
 
+static inline zval* zval_deref_safe(zval* z) {
+	if (z) { ZVAL_DEREF(z); }
+	return z;
+}
+
+/* Fetch zval*, resolving references
+ *
+ * zval *php_array_fetch_deref(zval *zarr, const char *key)
+ * zval *php_array_fetchl_deref(zval *zarr, const char *key, int key_len)
+ * zval *php_array_fetchl_safe_deref(zval *zarr, const char *key, int key_len)
+ * zval *php_array_fetchn_deref(zval *zarr, unsigned long idx)
+ * zval *php_array_fetchc_deref(zval *zarr, const char *litstr)
+ * zval *php_array_fetchz_deref(zval *zarr, zval *key)
+ */
+static inline
+zval *php_array_fetchl_deref(zval *zarr, const char *key, int key_len) {
+	return zval_deref_safe(php_array_fetchl(zarr, key, key_len));
+}
+static inline
+zval *php_array_fetch_deref(zval *zarr, const char *key) {
+	return zval_deref_safe(php_array_fetch(zarr, key));
+}
+#define php_array_fetchc_deref(zarr, litstr) zval_deref_safe(php_array_fetchl(zarr, litstr, sizeof(litstr)-1))
+static inline
+zval *php_array_fetchl_safe_deref(zval *zarr, const char *key, int key_len) {
+	return zval_deref_safe(php_array_fetchl_safe(zarr, key, key_len));
+}
+static inline
+zval *php_array_fetchn_deref(zval *zarr, zend_ulong idx) {
+	return zval_deref_safe(php_array_fetchn(zarr, idx));
+}
+static inline
+zval *php_array_fetchz_deref(zval *zarr, zval *key) {
+	return zval_deref_safe(php_array_fetchz(zarr, key));
+}
+
 #define PHP_ARRAY_FETCH_TYPE_MAP(ctype, ztype) \
 static inline ctype php_array_fetch_##ztype(zval *zarr, const char *key) \
-  	{ return php_array_zval_to_##ztype(php_array_fetch(zarr, key)); } \
+	{ return php_array_zval_to_##ztype(php_array_fetch_deref(zarr, key)); } \
 static inline ctype php_array_fetchl_##ztype(zval *zarr, const char *key, int key_len) \
-	{ return php_array_zval_to_##ztype(php_array_fetchl(zarr, key, key_len)); } \
+	{ return php_array_zval_to_##ztype(php_array_fetchl_deref(zarr, key, key_len)); } \
 static inline ctype php_array_fetchl_safe_##ztype(zval *zarr, const char *key, int key_len) \
-	{ return php_array_zval_to_##ztype(php_array_fetchl_safe(zarr, key, key_len)); } \
-static inline ctype php_array_fetchn_##ztype(zval *zarr, long idx) \
-	{ return php_array_zval_to_##ztype(php_array_fetchn(zarr, idx)); } \
+	{ return php_array_zval_to_##ztype(php_array_fetchl_safe_deref(zarr, key, key_len)); } \
+static inline ctype php_array_fetchn_##ztype(zval *zarr, zend_ulong idx) \
+	{ return php_array_zval_to_##ztype(php_array_fetchn_deref(zarr, idx)); } \
 static inline ctype php_array_fetchz_##ztype(zval *zarr, zval *key) \
-	{ return php_array_zval_to_##ztype(php_array_fetchz(zarr, key)); }
+	{ return php_array_zval_to_##ztype(php_array_fetchz_deref(zarr, key)); }
 
 /* Fetch zend_bool
  *
  * zend_bool php_array_fetch_bool(zval *zarr, const char *key)
  * zend_bool php_array_fetchl_bool(zval *zarr, const char *key, int key_len)
  * zend_bool php_array_fetchl_safe_bool(zval *zarr, const char *key, int key_len)
- * zend_bool php_array_fetchn_bool(zval *zarr, long idx)
+ * zend_bool php_array_fetchn_bool(zval *zarr, unsigned long idx)
  * zend_bool php_array_fetchc_bool(zval *zarr, const char *litstr)
  * zend_bool php_array_fetchz_bool(zval *zarr, zval *key)
  */
@@ -264,30 +250,28 @@ zend_bool php_array_zval_to_bool(zval *z) {
 }
 PHP_ARRAY_FETCH_TYPE_MAP(zend_bool, bool)
 #define php_array_fetchc_bool(zarr, litstr) \
-	php_array_zval_to_bool(php_array_fetchc(zarr, litstr))
+	php_array_zval_to_bool(php_array_fetchc_deref(zarr, litstr))
 
 /* Fetch long
  *
  * long php_array_fetch_long(zval *zarr, const char *key)
  * long php_array_fetchl_long(zval *zarr, const char *key, int key_len)
  * long php_array_fetchl_safe_long(zval *zarr, const char *key, int key_len)
- * long php_array_fetchn_long(zval *zarr, long idx)
+ * long php_array_fetchn_long(zval *zarr, unsigned long idx)
  * long php_array_fetchc_long(zval *zarr, const char *litstr)
  * long php_array_fetchz_long(zval *zarr, zval *key)
  */
 static inline
-long php_array_zval_to_long(zval *z) {
+zend_long php_array_zval_to_long(zval *z) {
 	if (!z) { return 0; }
 	switch(Z_TYPE_P(z)) {
-		case IS_NULL: return 0;
-#ifdef ZEND_ENGINE_3
-		case IS_FALSE: return 0;
-		case IS_TRUE: return 1;
-#else
-		case IS_BOOL: return Z_BVAL_P(z);
-#endif
-		case IS_LONG: return Z_LVAL_P(z);
-		case IS_DOUBLE: return (long)Z_DVAL_P(z);
+		case IS_NULL:
+		case IS_FALSE:
+			return 0;
+		case IS_TRUE:
+			return 1;
+		case IS_LONG:
+			return Z_LVAL_P(z);
 		default:
 		{
 			zval c = *z;
@@ -297,16 +281,16 @@ long php_array_zval_to_long(zval *z) {
 		}
 	}
 }
-PHP_ARRAY_FETCH_TYPE_MAP(long, long)
+PHP_ARRAY_FETCH_TYPE_MAP(zend_long, long)
 #define php_array_fetchc_long(zarr, litstr) \
-	php_array_zval_to_long(php_array_fetchc(zarr, litstr))
+	php_array_zval_to_long(php_array_fetchc_deref(zarr, litstr))
 
 /* Fetch double
  *
  * double php_array_fetch_double(zval *zarr, const char *key)
  * double php_array_fetchl_double(zval *zarr, const char *key, int key_len)
  * double php_array_fetchl_safe_double(zval *zarr, const char *key, int key_len)
- * double php_array_fetchn_double(zval *zarr, long idx)
+ * double php_array_fetchn_double(zval *zarr, unsigned long idx)
  * double php_array_fetchc_double(zval *zarr, const char *litstr)
  * double php_array_fetchz_double(zval *zarr, zval *key)
  */
@@ -314,15 +298,15 @@ static inline
 double php_array_zval_to_double(zval *z) {
 	if (!z) { return 0.0; }
 	switch (Z_TYPE_P(z)) {
-		case IS_NULL: return 0.0;
-#ifdef ZEND_ENGINE_3
-		case IS_FALSE: return 0.0;
-		case IS_TRUE: return 1.0;
-#else
-		case IS_BOOL: return (double)Z_BVAL_P(z);
-#endif
-		case IS_LONG: return (double)Z_LVAL_P(z);
-		case IS_DOUBLE: return Z_DVAL_P(z);
+		case IS_NULL:
+		case IS_FALSE:
+			return 0.0;
+		case IS_TRUE:
+			return 1.0;
+		case IS_LONG:
+			return (double) Z_LVAL_P(z);
+		case IS_DOUBLE:
+			return Z_DVAL_P(z);
 		default:
 		{
 			zval c = *z;
@@ -334,7 +318,7 @@ double php_array_zval_to_double(zval *z) {
 }
 PHP_ARRAY_FETCH_TYPE_MAP(double, double)
 #define php_array_fetchc_double(zarr, litstr) \
-	php_array_zval_to_double(php_array_fetchc(zarr, litstr))
+	php_array_zval_to_double(php_array_fetchc_deref(zarr, litstr))
 
 /* Fetch string
  *
@@ -346,7 +330,7 @@ PHP_ARRAY_FETCH_TYPE_MAP(double, double)
  * char *php_array_fetch_string(zval *zarr, const char *key, int *plen, zend_bool *pfree)
  * char *php_array_fetchl_string(zval *zarr, const char *key, int key_len, int *plen, zend_bool *pfree)
  * char *php_array_fetchl_safe_string(zval *zarr, const char *key, int key_len, int *plen, zend_bool *pfree)
- * char *php_array_fetchn_string(zval *zarr, long idx, int *plen, zend_bool *pfree)
+ * char *php_array_fetchn_string(zval *zarr, unsigned long idx, int *plen, zend_bool *pfree)
  * char *php_array_fetchc_string(zval *zarr, const char *litstr, int *plen, zend_bool *pfree)
  * char *php_array_fetchz_string(zval *zarr, zval *key, int *plen, zend_bool *pfree)
  */
@@ -357,7 +341,7 @@ char *php_array_zval_to_string(zval *z, int *plen, zend_bool *pfree) {
 	if (!z) { return NULL; }
 	switch (Z_TYPE_P(z)) {
 		case IS_NULL:
-			return (char *)"";
+			return (char *) "";
 		case IS_STRING:
 			*plen = Z_STRLEN_P(z);
 			return Z_STRVAL_P(z);
@@ -366,28 +350,24 @@ char *php_array_zval_to_string(zval *z, int *plen, zend_bool *pfree) {
 			zval c = *z;
 			zval_copy_ctor(&c);
 			convert_to_string(&c);
-#ifdef ZEND_ENGINE_3
 			*pfree = ! IS_INTERNED(Z_STR(c));
-#else
-			*pfree = ! IS_INTERNED(Z_STRVAL(c));
-#endif
 			*plen = Z_STRLEN(c);
 			return Z_STRVAL(c);
 		}
 	}
 }
 #define php_array_fetch_string(zarr, key, plen, pfree) \
-	php_array_zval_to_string(php_array_fetch(zarr, key), plen, pfree)
+	php_array_zval_to_string(php_array_fetch_deref(zarr, key), plen, pfree)
 #define php_array_fetchl_string(zarr, key, key_len, plen, pfree) \
-	php_array_zval_to_string(php_array_fetchl(zarr, key, key_len), plen, pfree)
+	php_array_zval_to_string(php_array_fetchl_deref(zarr, key, key_len), plen, pfree)
 #define php_array_fetchl_safe_string(zarr, key, key_len, plen, pfree) \
-	php_array_zval_to_string(php_array_fetchl_safe(zarr, key, key_len), plen, pfree)
+	php_array_zval_to_string(php_array_fetchl_safe_deref(zarr, key, key_le), plen, pfree)
 #define php_array_fetchn_string(zarr, idx, plen, pfree) \
-	php_array_zval_to_string(php_array_fetchn(zarr, idx), plen, pfree)
+	php_array_zval_to_string(php_array_fetchn_deref(zarr, idx), plen, pfree)
 #define php_array_fetchc_string(zarr, litstr, plen, pfree) \
-	php_array_zval_to_string(php_array_fetchc(zarr, litstr), plen, pfree)
+	php_array_zval_to_string(php_array_fetchc_deref(zarr, litstr), plen, pfree)
 #define php_array_fetchz_string(zarr, key, plen, pfree) \
-	php_array_zval_to_string(php_array_fetchz(zarr, key), plen, pfree)
+	php_array_zval_to_string(php_array_fetchz_deref(zarr, key), plen, pfree)
 
 
 /* Fetch array
@@ -400,16 +380,16 @@ char *php_array_zval_to_string(zval *z, int *plen, zend_bool *pfree) {
  * zval *php_array_fetch_array(zval *zarr, const char *key)
  * zval *php_array_fetchl_array(zval *zarr, const char *key, int key_len)
  * zval *php_array_fetchl_safe_array(zval *zarr, const char *key, int key_len)
- * zval *php_array_fetchn_array(zval *zarr, long idx)
+ * zval *php_array_fetchn_array(zval *zarr, unsigned long idx)
  * zval *php_array_fetchc_array(zval *zarr, const char *litstr)
  * zval *php_array_fetchz_array(zval *zarr, zval *key)
  */
 static inline zval *php_array_zval_to_array(zval *zarr) {
-	return (zarr && (Z_TYPE_P(zarr) == IS_ARRAY)) ? zarr : NULL;
+	return zarr && Z_TYPE_P(zarr) == IS_ARRAY ? zarr : NULL;
 }
 PHP_ARRAY_FETCH_TYPE_MAP(zval*, array)
 #define php_array_fetchc_array(zarr, litstr) \
-	php_array_zval_to_array(php_array_fetchc(zarr, litstr))
+	php_array_zval_to_array(php_array_fetchc_deref(zarr, litstr))
 
 /* count($arr) - Count number of elements in the array
  *
@@ -431,37 +411,26 @@ PHP_ARRAY_FETCH_TYPE_MAP(zval*, array)
  * zval *php_array_fetch_resource(zval *zarr, const char *key, int le)
  * zval *php_array_fetchl_resource(zval *zarr, const char *key, int key_len, int le)
  * zval *php_array_fetchl_safe_resource(zval *zarr, const char *key, int key_len, int le)
- * zval *php_array_fetchn_resource(zval *zarr, long idx, int le)
+ * zval *php_array_fetchn_resource(zval *zarr, unsigned long idx, int le)
  * zval *php_array_fetchc_resource(zval *zarr, const char *litstr, int le)
  * zval *php_array_fetchz_resource(zval *zarr, zval *key, int le)
  */
 static inline
-void *php_array_zval_to_resource(zval *z, int le TSRMLS_DC) {
-#ifdef ZEND_ENGINE_3
+void *php_array_zval_to_resource(zval *z, int le) {
 	return zend_fetch_resource_ex(z, NULL, le);
-#else
-	void *ret;
-	int rtype;
- 	if (!z || Z_TYPE_P(z) != IS_RESOURCE) { return NULL; }
-	ret = zend_list_find(Z_RESVAL_P(z), &rtype);
-	if (!ret || (rtype != le)) {
-		return NULL;
-	}
-	return ret;
-#endif
 }
 #define php_array_fetch_resource(zarr, key, le) \
-	php_array_zval_to_resource(php_array_fetch(zarr, key), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetch_deref(zarr, key), le)
 #define php_array_fetchl_resource(zarr, key, key_len, le) \
-	php_array_zval_to_resource(php_array_fetchl(zarr, key, key_len), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetchl_deref(zarr, key, key_len), le)
 #define php_array_fetchl_safe_resource(zarr, key, key_len, le) \
-	php_array_zval_to_resource(php_array_fetchl_safe(zarr, key, key_len), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetchl_safe_deref(zarr, key, key_len), le)
 #define php_array_fetchn_resource(zarr, idx, le) \
-	php_array_zval_to_resource(php_array_fetchn(zarr, idx), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetchn_deref(zarr, idx), le)
 #define php_array_fetchc_resource(zarr, litstr, le) \
-	php_array_zval_to_resource(php_array_fetchc(zarr, litstr), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetchc_deref(zarr, litstr), le)
 #define php_array_fetchz_resource(zarr, key, le) \
-        php_array_zval_to_resource(php_array_fetchz(zarr, key), le TSRMLS_CC)
+	php_array_zval_to_resource(php_array_fetchz_deref(zarr, key), le)
 
 /* Fetch Object
  *
@@ -472,27 +441,27 @@ void *php_array_zval_to_resource(zval *z, int le TSRMLS_DC) {
  * zval *php_array_fetch_object(zval *zarr, const char *key, zend_class_entry *ce)
  * zval *php_array_fetchl_object(zval *zarr, const char *key, int key_len, zend_class_entry *ce)
  * zval *php_array_fetchl_safe_object(zval *zarr, const char *key, int key_len, zend_class_entry *ce)
- * zval *php_array_fetchn_object(zval *zarr, long idx, zend_class_entry *ce)
+ * zval *php_array_fetchn_object(zval *zarr, unsigned long idx, zend_class_entry *ce)
  * zval *php_array_fetchc_object(zval *zarr, const char *litstr, zend_class_entry *ce)
  * zval *php_array_fetchz_object(zval *zarr, zval *key, zend_class_entry *ce)
  */
 static inline
-zval *php_array_zval_to_object(zval *z, zend_class_entry *ce TSRMLS_DC) {
-	return (z && (Z_TYPE_P(z) == IS_OBJECT) &&
-	        ((!ce) || instanceof_function(Z_OBJCE_P(z), ce TSRMLS_CC))) ? z : NULL;
+zval *php_array_zval_to_object(zval *z, zend_class_entry *ce) {
+	if (!z || Z_TYPE_P(z) != IS_OBJECT) { return NULL; }
+	return (!ce) || instanceof_function(Z_OBJCE_P(z), ce) ? z : NULL;
 }
 #define php_array_fetch_object(zarr, key, ce) \
-	php_array_zval_to_object(php_array_fetch(zarr, key), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetch_deref(zarr, key), ce)
 #define php_array_fetchl_object(zarr, key, len, ce) \
-	php_array_zval_to_object(php_array_fetchl(zarr, key, len), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetchl_deref(zarr, key, len), ce)
 #define php_array_fetchl_safe_object(zarr, key, len, ce) \
-	php_array_zval_to_object(php_array_fetchl_safe(zarr, key, len), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetchl_safe_deref(zarr, key, len), ce)
 #define php_array_fetchn_object(zarr, idx, ce) \
-	php_array_zval_to_object(php_array_fetchn(zarr, idx), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetchn_deref(zarr, idx), ce)
 #define php_array_fetchc_object(zarr, litstr, ce) \
-	php_array_zval_to_object(php_array_fetchc(zarr, litstr), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetchc_deref(zarr, litstr), ce)
 #define php_array_fetchz_object(zarr, key, ce) \
-        php_array_zval_to_object(php_array_fetchz(zarr, key), ce TSRMLS_CC)
+	php_array_zval_to_object(php_array_fetchz_deref(zarr, key), ce)
 
 /* unset($zarr[$key]) - Erase a key from an array
  *
@@ -505,45 +474,34 @@ zval *php_array_zval_to_object(zval *z, zend_class_entry *ce TSRMLS_DC) {
  */
 static inline
 void php_array_unset(zval *zarr, const char *key) {
-	PAA_SYM_DEL(Z_ARRVAL_P(zarr), key, PAA_LENGTH_ADJ(strlen(key)));
+	zend_symtable_str_del(Z_ARRVAL_P(zarr), key, strlen(key));
 }
 #define php_array_unsetl(zarr, key, len) \
-	PAA_SYM_DEL(Z_ARRVAL_P(zarr), key, PAA_LENGTH_ADJ(len))
+	zend_symtable_str_del(Z_ARRVAL_P(zarr), key, len)
 static inline
 void php_array_unsetl_safe(zval *zarr, const char *key, int key_len) {
 	char *k = estrndup(key, key_len);
-	PAA_SYM_DEL(Z_ARRVAL_P(zarr), k, PAA_LENGTH_ADJ(key_len));
+	zend_symtable_str_del(Z_ARRVAL_P(zarr), k, key_len);
 	efree(k);
 }
 #define php_array_unsetn(zarr, idx) \
 	zend_symtable_index_del(Z_ARRVAL_P(zarr), idx)
-#ifdef ZEND_ENGINE_3
-# define php_array_unsetc(zarr, litstr) \
-	zend_symtable_str_del(Z_ARRVAL_P(zarr), litstr, PAA_LENGTH_ADJ(sizeof(litstr) - 1))
-#else
-# define php_array_unsetc(zarr, litstr) \
-	zend_symtable_del(Z_ARRVAL_P(zarr), litstr, PAA_LENGTH_ADJ(sizeof(litstr) - 1))
-#endif
+#define php_array_unsetc(zarr, litstr) \
+	zend_symtable_str_del(Z_ARRVAL_P(zarr), litstr, sizeof(litstr) - 1)
 static inline void php_array_unsetz(zval *zarr, zval *key) {
 	switch (Z_TYPE_P(key)) {
 		case IS_NULL:
-			zend_hash_index_del(Z_ARRVAL_P(zarr), 0);
-			return;
-#ifdef ZEND_ENGINE_3
 		case IS_FALSE:
 			zend_hash_index_del(Z_ARRVAL_P(zarr), 0);
 			return;
 		case IS_TRUE:
 			zend_hash_index_del(Z_ARRVAL_P(zarr), 1);
 			return;
-#else
-		case IS_BOOL: /* fallthrough */
-#endif
 		case IS_LONG:
 			zend_hash_index_del(Z_ARRVAL_P(zarr), Z_LVAL_P(key));
 			return;
 		case IS_DOUBLE:
-			zend_hash_index_del(Z_ARRVAL_P(zarr), (long)Z_DVAL_P(key));
+			zend_hash_index_del(Z_ARRVAL_P(zarr), (zend_ulong) Z_DVAL_P(key));
 			break;
 		case IS_STRING:
 			php_array_unsetl(zarr, Z_STRVAL_P(key), Z_STRLEN_P(key));
