@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "bson/bson-prelude.h"
+#include <bson/bson-prelude.h>
 
 
 #ifndef BSON_TYPES_H
@@ -24,10 +24,10 @@
 #include <stdlib.h>
 #include <sys/types.h>
 
-#include "bson/bson-macros.h"
-#include "bson/bson-config.h"
-#include "bson/bson-compat.h"
-#include "bson/bson-endian.h"
+#include <bson/bson-macros.h>
+#include <bson/bson-config.h>
+#include <bson/bson-compat.h>
+#include <bson/bson-endian.h>
 
 BSON_BEGIN_DECLS
 
@@ -51,25 +51,21 @@ typedef uint32_t bson_unichar_t;
 
 
 /**
- * bson_context_flags_t:
- *
- * This enumeration is used to configure a bson_context_t.
- *
- * %BSON_CONTEXT_NONE: Use default options.
- * %BSON_CONTEXT_THREAD_SAFE: Context will be called from multiple threads.
- * %BSON_CONTEXT_DISABLE_PID_CACHE: Call getpid() instead of caching the
- *   result of getpid() when initializing the context.
- * %BSON_CONTEXT_DISABLE_HOST_CACHE: Call gethostname() instead of caching the
- *   result of gethostname() when initializing the context.
+ * @brief Flags configuring the creation of a bson_context_t
  */
 typedef enum {
+   /** Use default options */
    BSON_CONTEXT_NONE = 0,
+   /* Deprecated: Generating new OIDs from a bson_context_t is always
+      thread-safe */
    BSON_CONTEXT_THREAD_SAFE = (1 << 0),
+   /* Deprecated: Does nothing and is ignored */
    BSON_CONTEXT_DISABLE_HOST_CACHE = (1 << 1),
+   /* Call getpid() instead of remembering the result of getpid() when using the
+      context */
    BSON_CONTEXT_DISABLE_PID_CACHE = (1 << 2),
-#ifdef BSON_HAVE_SYSCALL_TID
+   /* Deprecated: Does nothing */
    BSON_CONTEXT_USE_TASK_ID = (1 << 3),
-#endif
 } bson_context_flags_t;
 
 
@@ -98,6 +94,17 @@ typedef enum {
  */
 typedef struct _bson_context_t bson_context_t;
 
+/**
+ * bson_json_opts_t:
+ *
+ * This structure is used to pass options for serializing BSON into extended
+ * JSON to the respective serialization methods.
+ *
+ * max_len can be either a non-negative integer, or BSON_MAX_LEN_UNLIMITED to
+ * set no limit for serialization length.
+ */
+typedef struct _bson_json_opts_t bson_json_opts_t;
+
 
 /**
  * bson_t:
@@ -117,23 +124,20 @@ typedef struct _bson_context_t bson_context_t;
  * This structure is meant to fit in two sequential 64-byte cachelines.
  */
 #ifdef BSON_MEMCHECK
-BSON_ALIGNED_BEGIN (128)
-typedef struct _bson_t {
-   uint32_t flags;       /* Internal flags for the bson_t. */
-   uint32_t len;         /* Length of BSON data. */
-   char *canary;         /* For valgrind check */
-   uint8_t padding[120 - sizeof (char*)];
+BSON_ALIGNED_BEGIN (128) typedef struct _bson_t {
+   uint32_t flags; /* Internal flags for the bson_t. */
+   uint32_t len;   /* Length of BSON data. */
+   char *canary;   /* For leak checks. */
+   uint8_t padding[120 - sizeof (char *)];
 } bson_t BSON_ALIGNED_END (128);
 #else
-BSON_ALIGNED_BEGIN (128)
-typedef struct _bson_t {
+BSON_ALIGNED_BEGIN (128) typedef struct _bson_t {
    uint32_t flags;       /* Internal flags for the bson_t. */
    uint32_t len;         /* Length of BSON data. */
    uint8_t padding[120]; /* Padding for stack allocation. */
 } bson_t BSON_ALIGNED_END (128);
 #endif
 
-
 /**
  * BSON_INITIALIZER:
  *
@@ -145,13 +149,9 @@ typedef struct _bson_t {
  * ]|
  */
 #ifdef BSON_MEMCHECK
-#define BSON_INITIALIZER \
-   {                     \
-      3, 5,              \
-      bson_malloc (1),   \
-      {                  \
-         5               \
-      },                 \
+#define BSON_INITIALIZER          \
+   {                              \
+      3, 5, bson_malloc (1), {5}, \
    }
 #else
 #define BSON_INITIALIZER \
@@ -271,6 +271,9 @@ typedef enum {
    BSON_SUBTYPE_UUID_DEPRECATED = 0x03,
    BSON_SUBTYPE_UUID = 0x04,
    BSON_SUBTYPE_MD5 = 0x05,
+   BSON_SUBTYPE_ENCRYPTED = 0x06,
+   BSON_SUBTYPE_COLUMN = 0x07,
+   BSON_SUBTYPE_SENSITIVE = 0x08,
    BSON_SUBTYPE_USER = 0x80,
 } bson_subtype_t;
 
@@ -382,11 +385,10 @@ typedef struct {
  * memory allocations under certain circumstances such as reading from an
  * incoming mongo packet.
  */
-
 BSON_ALIGNED_BEGIN (BSON_ALIGN_OF_PTR)
 typedef struct {
    uint32_t type;
-   /*< private >*/
+   /**< private >**/
 } bson_reader_t BSON_ALIGNED_END (BSON_ALIGN_OF_PTR);
 
 
@@ -413,23 +415,10 @@ typedef struct {
    /* corrupt BSON, or unsupported type and visit_unsupported_type not set */
    void (*visit_corrupt) (const bson_iter_t *iter, void *data);
    /* normal bson field callbacks */
-   bool (*visit_double) (const bson_iter_t *iter,
-                         const char *key,
-                         double v_double,
-                         void *data);
-   bool (*visit_utf8) (const bson_iter_t *iter,
-                       const char *key,
-                       size_t v_utf8_len,
-                       const char *v_utf8,
-                       void *data);
-   bool (*visit_document) (const bson_iter_t *iter,
-                           const char *key,
-                           const bson_t *v_document,
-                           void *data);
-   bool (*visit_array) (const bson_iter_t *iter,
-                        const char *key,
-                        const bson_t *v_array,
-                        void *data);
+   bool (*visit_double) (const bson_iter_t *iter, const char *key, double v_double, void *data);
+   bool (*visit_utf8) (const bson_iter_t *iter, const char *key, size_t v_utf8_len, const char *v_utf8, void *data);
+   bool (*visit_document) (const bson_iter_t *iter, const char *key, const bson_t *v_document, void *data);
+   bool (*visit_array) (const bson_iter_t *iter, const char *key, const bson_t *v_array, void *data);
    bool (*visit_binary) (const bson_iter_t *iter,
                          const char *key,
                          bson_subtype_t v_subtype,
@@ -437,70 +426,37 @@ typedef struct {
                          const uint8_t *v_binary,
                          void *data);
    /* normal field with deprecated "Undefined" BSON type */
-   bool (*visit_undefined) (const bson_iter_t *iter,
-                            const char *key,
-                            void *data);
-   bool (*visit_oid) (const bson_iter_t *iter,
-                      const char *key,
-                      const bson_oid_t *v_oid,
-                      void *data);
-   bool (*visit_bool) (const bson_iter_t *iter,
-                       const char *key,
-                       bool v_bool,
-                       void *data);
-   bool (*visit_date_time) (const bson_iter_t *iter,
-                            const char *key,
-                            int64_t msec_since_epoch,
-                            void *data);
+   bool (*visit_undefined) (const bson_iter_t *iter, const char *key, void *data);
+   bool (*visit_oid) (const bson_iter_t *iter, const char *key, const bson_oid_t *v_oid, void *data);
+   bool (*visit_bool) (const bson_iter_t *iter, const char *key, bool v_bool, void *data);
+   bool (*visit_date_time) (const bson_iter_t *iter, const char *key, int64_t msec_since_epoch, void *data);
    bool (*visit_null) (const bson_iter_t *iter, const char *key, void *data);
-   bool (*visit_regex) (const bson_iter_t *iter,
-                        const char *key,
-                        const char *v_regex,
-                        const char *v_options,
-                        void *data);
+   bool (*visit_regex) (
+      const bson_iter_t *iter, const char *key, const char *v_regex, const char *v_options, void *data);
    bool (*visit_dbpointer) (const bson_iter_t *iter,
                             const char *key,
                             size_t v_collection_len,
                             const char *v_collection,
                             const bson_oid_t *v_oid,
                             void *data);
-   bool (*visit_code) (const bson_iter_t *iter,
-                       const char *key,
-                       size_t v_code_len,
-                       const char *v_code,
-                       void *data);
-   bool (*visit_symbol) (const bson_iter_t *iter,
-                         const char *key,
-                         size_t v_symbol_len,
-                         const char *v_symbol,
-                         void *data);
+   bool (*visit_code) (const bson_iter_t *iter, const char *key, size_t v_code_len, const char *v_code, void *data);
+   bool (*visit_symbol) (
+      const bson_iter_t *iter, const char *key, size_t v_symbol_len, const char *v_symbol, void *data);
    bool (*visit_codewscope) (const bson_iter_t *iter,
                              const char *key,
                              size_t v_code_len,
                              const char *v_code,
                              const bson_t *v_scope,
                              void *data);
-   bool (*visit_int32) (const bson_iter_t *iter,
-                        const char *key,
-                        int32_t v_int32,
-                        void *data);
-   bool (*visit_timestamp) (const bson_iter_t *iter,
-                            const char *key,
-                            uint32_t v_timestamp,
-                            uint32_t v_increment,
-                            void *data);
-   bool (*visit_int64) (const bson_iter_t *iter,
-                        const char *key,
-                        int64_t v_int64,
-                        void *data);
+   bool (*visit_int32) (const bson_iter_t *iter, const char *key, int32_t v_int32, void *data);
+   bool (*visit_timestamp) (
+      const bson_iter_t *iter, const char *key, uint32_t v_timestamp, uint32_t v_increment, void *data);
+   bool (*visit_int64) (const bson_iter_t *iter, const char *key, int64_t v_int64, void *data);
    bool (*visit_maxkey) (const bson_iter_t *iter, const char *key, void *data);
    bool (*visit_minkey) (const bson_iter_t *iter, const char *key, void *data);
    /* if set, called instead of visit_corrupt when an apparently valid BSON
     * includes an unrecognized field type (reading future version of BSON) */
-   void (*visit_unsupported_type) (const bson_iter_t *iter,
-                                   const char *key,
-                                   uint32_t type_code,
-                                   void *data);
+   void (*visit_unsupported_type) (const bson_iter_t *iter, const char *key, uint32_t type_code, void *data);
    bool (*visit_decimal128) (const bson_iter_t *iter,
                              const char *key,
                              const bson_decimal128_t *v_decimal128,
