@@ -15,22 +15,24 @@
  */
 
 
-#include "mongoc-cursor.h"
-#include "mongoc-cursor-private.h"
-#include "mongoc-client-private.h"
-#include "mongoc-client-session-private.h"
-#include "mongoc-counters-private.h"
-#include "mongoc-error.h"
-#include "mongoc-error-private.h"
-#include "mongoc-log.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-read-concern-private.h"
-#include "mongoc-util-private.h"
-#include "mongoc-write-concern-private.h"
-#include "mongoc-read-prefs-private.h"
-#include "mongoc-aggregate-private.h"
+#include <mongoc/mongoc-cursor.h>
+#include <mongoc/mongoc-cursor-private.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-client-session-private.h>
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-error.h>
+#include <mongoc/mongoc-error-private.h>
+#include <mongoc/mongoc-log.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-read-concern-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <mongoc/mongoc-write-concern-private.h>
+#include <mongoc/mongoc-read-prefs-private.h>
+#include <mongoc/mongoc-aggregate-private.h>
+#include <mongoc/mongoc-structured-log-private.h>
 
-#include <bson-dsl.h>
+#include <common-bson-dsl-private.h>
+#include <common-cmp-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "cursor"
@@ -112,7 +114,7 @@ _mongoc_n_return (mongoc_cursor_t *cursor)
    int64_t n_return;
 
    /* calculate numberToReturn according to:
-    * https://github.com/mongodb/specifications/blob/master/source/crud/crud.rst#combining-limit-and-batch-size-for-the-wire-protocol
+    * https://github.com/mongodb/specifications/blob/master/source/crud/crud.md#combining-limit-and-batch-size-for-the-wire-protocol
     */
    limit = mongoc_cursor_get_limit (cursor);
    batch_size = mongoc_cursor_get_batch_size (cursor);
@@ -582,7 +584,7 @@ mongoc_cursor_destroy (mongoc_cursor_t *cursor)
 
 
 mongoc_server_stream_t *
-_mongoc_cursor_fetch_stream (mongoc_cursor_t *cursor)
+_mongoc_cursor_fetch_stream (mongoc_cursor_t *cursor, const mongoc_ss_log_context_t *log_context)
 {
    mongoc_server_stream_t *server_stream;
    bson_t reply;
@@ -604,12 +606,20 @@ _mongoc_cursor_fetch_stream (mongoc_cursor_t *cursor)
          server_stream->must_use_primary = cursor->must_use_primary;
       }
    } else {
-      server_stream =
-         cursor->is_aggr_with_write_stage
-            ? mongoc_cluster_stream_for_aggr_with_write (
-                 &cursor->client->cluster, cursor->read_prefs, cursor->client_session, &reply, &cursor->error)
-            : mongoc_cluster_stream_for_reads (
-                 &cursor->client->cluster, cursor->read_prefs, cursor->client_session, NULL, &reply, &cursor->error);
+      server_stream = cursor->is_aggr_with_write_stage
+                         ? mongoc_cluster_stream_for_aggr_with_write (&cursor->client->cluster,
+                                                                      log_context,
+                                                                      cursor->read_prefs,
+                                                                      cursor->client_session,
+                                                                      &reply,
+                                                                      &cursor->error)
+                         : mongoc_cluster_stream_for_reads (&cursor->client->cluster,
+                                                            log_context,
+                                                            cursor->read_prefs,
+                                                            cursor->client_session,
+                                                            NULL,
+                                                            &reply,
+                                                            &cursor->error);
 
       if (server_stream) {
          /* Remember the selected server_id and whether primary read mode was
@@ -636,14 +646,27 @@ _mongoc_cursor_monitor_command (mongoc_cursor_t *cursor,
                                 const bson_t *cmd,
                                 const char *cmd_name)
 {
-   mongoc_client_t *client;
    mongoc_apm_command_started_t event;
    char *db;
 
    ENTRY;
 
-   client = cursor->client;
-   if (!client->apm_callbacks.started) {
+   mongoc_client_t *client = cursor->client;
+   const mongoc_log_and_monitor_instance_t *log_and_monitor = &client->topology->log_and_monitor;
+
+   mongoc_structured_log (
+      log_and_monitor->structured_log,
+      MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+      MONGOC_STRUCTURED_LOG_COMPONENT_COMMAND,
+      "Command started",
+      int32 ("requestId", client->cluster.request_id),
+      server_description (server_stream->sd, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID, SERVICE_ID),
+      utf8_n ("databaseName", cursor->ns, cursor->dblen),
+      utf8 ("commandName", cmd_name),
+      int64 ("operationId", cursor->operation_id),
+      bson_as_json ("command", cmd));
+
+   if (!log_and_monitor->apm_callbacks.started) {
       /* successful */
       RETURN (true);
    }
@@ -661,9 +684,9 @@ _mongoc_cursor_monitor_command (mongoc_cursor_t *cursor,
                                     &server_stream->sd->service_id,
                                     server_stream->sd->server_connection_id,
                                     NULL,
-                                    client->apm_context);
+                                    log_and_monitor->apm_context);
 
-   client->apm_callbacks.started (&event);
+   log_and_monitor->apm_callbacks.started (&event);
    mongoc_apm_command_started_cleanup (&event);
    bson_free (db);
 
@@ -703,15 +726,11 @@ _mongoc_cursor_monitor_succeeded (mongoc_cursor_t *cursor,
 {
    bson_t docs_array;
    mongoc_apm_command_succeeded_t event;
-   mongoc_client_t *client;
 
    ENTRY;
 
-   client = cursor->client;
-
-   if (!client->apm_callbacks.succeeded) {
-      EXIT;
-   }
+   mongoc_client_t *client = cursor->client;
+   const mongoc_log_and_monitor_instance_t *log_and_monitor = &client->topology->log_and_monitor;
 
    /* we sent OP_QUERY/OP_GETMORE, fake a reply to find/getMore command:
     * {ok: 1, cursor: {id: 17, ns: "...", first/nextBatch: [ ... docs ... ]}}
@@ -729,23 +748,38 @@ _mongoc_cursor_monitor_succeeded (mongoc_cursor_t *cursor,
 
    bson_destroy (&docs_array);
 
-   mongoc_apm_command_succeeded_init (&event,
-                                      duration,
-                                      &reply,
-                                      cmd_name,
-                                      db,
-                                      client->cluster.request_id,
-                                      cursor->operation_id,
-                                      &stream->sd->host,
-                                      stream->sd->id,
-                                      &stream->sd->service_id,
-                                      stream->sd->server_connection_id,
-                                      false,
-                                      client->apm_context);
+   mongoc_structured_log (log_and_monitor->structured_log,
+                          MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+                          MONGOC_STRUCTURED_LOG_COMPONENT_COMMAND,
+                          "Command succeeded",
+                          int32 ("requestId", client->cluster.request_id),
+                          server_description (stream->sd, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID, SERVICE_ID),
+                          utf8 ("databaseName", db),
+                          utf8 ("commandName", cmd_name),
+                          int64 ("operationId", cursor->operation_id),
+                          monotonic_time_duration (duration),
+                          cmd_name_reply (cmd_name, &reply));
 
-   client->apm_callbacks.succeeded (&event);
+   if (log_and_monitor->apm_callbacks.succeeded) {
+      mongoc_apm_command_succeeded_init (&event,
+                                         duration,
+                                         &reply,
+                                         cmd_name,
+                                         db,
+                                         client->cluster.request_id,
+                                         cursor->operation_id,
+                                         &stream->sd->host,
+                                         stream->sd->id,
+                                         &stream->sd->service_id,
+                                         stream->sd->server_connection_id,
+                                         false,
+                                         log_and_monitor->apm_context);
+
+      log_and_monitor->apm_callbacks.succeeded (&event);
+
+      mongoc_apm_command_succeeded_cleanup (&event);
+   }
 
-   mongoc_apm_command_succeeded_cleanup (&event);
    bson_destroy (&reply);
    bson_free (db);
 
@@ -760,15 +794,11 @@ _mongoc_cursor_monitor_failed (mongoc_cursor_t *cursor,
                                const char *cmd_name)
 {
    mongoc_apm_command_failed_t event;
-   mongoc_client_t *client;
 
    ENTRY;
 
-   client = cursor->client;
-
-   if (!client->apm_callbacks.failed) {
-      EXIT;
-   }
+   mongoc_client_t *client = cursor->client;
+   const mongoc_log_and_monitor_instance_t *log_and_monitor = &client->topology->log_and_monitor;
 
    /* we sent OP_QUERY/OP_GETMORE, fake a reply to find/getMore command:
     * {ok: 0}
@@ -776,24 +806,39 @@ _mongoc_cursor_monitor_failed (mongoc_cursor_t *cursor,
    bsonBuildDecl (reply, kv ("ok", int32 (0)));
    char *db = bson_strndup (cursor->ns, cursor->dblen);
 
-   mongoc_apm_command_failed_init (&event,
-                                   duration,
-                                   cmd_name,
-                                   db,
-                                   &cursor->error,
-                                   &reply,
-                                   client->cluster.request_id,
-                                   cursor->operation_id,
-                                   &stream->sd->host,
-                                   stream->sd->id,
-                                   &stream->sd->service_id,
-                                   stream->sd->server_connection_id,
-                                   false,
-                                   client->apm_context);
+   mongoc_structured_log (log_and_monitor->structured_log,
+                          MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+                          MONGOC_STRUCTURED_LOG_COMPONENT_COMMAND,
+                          "Command failed",
+                          int32 ("requestId", client->cluster.request_id),
+                          server_description (stream->sd, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID, SERVICE_ID),
+                          utf8 ("databaseName", db),
+                          utf8 ("commandName", cmd_name),
+                          int64 ("operationId", cursor->operation_id),
+                          monotonic_time_duration (duration),
+                          bson_as_json ("failure", &reply));
 
-   client->apm_callbacks.failed (&event);
+   if (log_and_monitor->apm_callbacks.failed) {
+      mongoc_apm_command_failed_init (&event,
+                                      duration,
+                                      cmd_name,
+                                      db,
+                                      &cursor->error,
+                                      &reply,
+                                      client->cluster.request_id,
+                                      cursor->operation_id,
+                                      &stream->sd->host,
+                                      stream->sd->id,
+                                      &stream->sd->service_id,
+                                      stream->sd->server_connection_id,
+                                      false,
+                                      log_and_monitor->apm_context);
+
+      log_and_monitor->apm_callbacks.failed (&event);
+
+      mongoc_apm_command_failed_cleanup (&event);
+   }
 
-   mongoc_apm_command_failed_cleanup (&event);
    bson_destroy (&reply);
    bson_free (db);
 
@@ -875,7 +920,6 @@ _mongoc_cursor_run_command (
    mongoc_server_stream_t *server_stream;
    bson_iter_t iter;
    mongoc_cmd_parts_t parts;
-   const char *cmd_name;
    bool is_primary;
    mongoc_read_prefs_t *prefs = NULL;
    char *db = NULL;
@@ -885,11 +929,16 @@ _mongoc_cursor_run_command (
 
    ENTRY;
 
+   const char *cmd_name = _mongoc_get_command_name (command);
+
    mongoc_cmd_parts_init (&parts, cursor->client, db, MONGOC_QUERY_NONE, command);
    parts.is_read_command = true;
    parts.read_prefs = cursor->read_prefs;
    parts.assembled.operation_id = cursor->operation_id;
-   server_stream = _mongoc_cursor_fetch_stream (cursor);
+
+   const mongoc_ss_log_context_t ss_log_context = {
+      .operation = cmd_name, .has_operation_id = true, .operation_id = parts.assembled.operation_id};
+   server_stream = _mongoc_cursor_fetch_stream (cursor, &ss_log_context);
 
    if (!server_stream) {
       _mongoc_bson_init_if_set (reply);
@@ -971,7 +1020,6 @@ _mongoc_cursor_run_command (
     * OP_QUERY we handle this by setting secondaryOk. here we use
     * $readPreference.
     */
-   cmd_name = _mongoc_get_command_name (command);
    is_primary = !cursor->read_prefs || cursor->read_prefs->mode == MONGOC_READ_PRIMARY;
 
    if (strcmp (cmd_name, "getMore") != 0 && is_primary && parts.user_query_flags & MONGOC_QUERY_SECONDARY_OK) {
@@ -1026,8 +1074,13 @@ retry:
 
          BSON_ASSERT (!cursor->is_aggr_with_write_stage && "Cannot attempt a retry on an aggregate operation that "
                                                            "contains write stages");
-         server_stream = mongoc_cluster_stream_for_reads (
-            &cursor->client->cluster, cursor->read_prefs, cursor->client_session, ds, reply, &cursor->error);
+         server_stream = mongoc_cluster_stream_for_reads (&cursor->client->cluster,
+                                                          &ss_log_context,
+                                                          cursor->read_prefs,
+                                                          cursor->client_session,
+                                                          ds,
+                                                          reply,
+                                                          &cursor->error);
 
          mongoc_deprioritized_servers_destroy (ds);
       }
@@ -1369,7 +1422,7 @@ mongoc_cursor_set_batch_size (mongoc_cursor_t *cursor, uint32_t batch_size)
    } else if (BSON_ITER_HOLDS_INT64 (&iter)) {
       bson_iter_overwrite_int64 (&iter, (int64_t) batch_size);
    } else if (BSON_ITER_HOLDS_INT32 (&iter)) {
-      if (!bson_in_range_int32_t_unsigned (batch_size)) {
+      if (!mcommon_in_range_int32_t_unsigned (batch_size)) {
          MONGOC_WARNING ("unable to overwrite stored int32 batchSize with "
                          "out-of-range value %" PRIu32,
                          batch_size);
@@ -1676,7 +1729,8 @@ _mongoc_cursor_prepare_getmore_command (mongoc_cursor_t *cursor, bson_t *command
        *
        * Since this function has no error reporting, we also no-op if we cannot
        * fetch a stream. */
-      server_stream = _mongoc_cursor_fetch_stream (cursor);
+      const mongoc_ss_log_context_t ss_log_context = {.operation = "getMore"};
+      server_stream = _mongoc_cursor_fetch_stream (cursor, &ss_log_context);
 
       if (server_stream != NULL && server_stream->sd->max_wire_version >= WIRE_VERSION_4_4) {
          bson_append_value (command, MONGOC_CURSOR_COMMENT, MONGOC_CURSOR_COMMENT_LEN, comment);
