@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-config.h"
+#include <mongoc/mongoc-config.h>
 
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
 
@@ -29,18 +29,18 @@
 
 #include <string.h>
 
-#include "mongoc-http-private.h"
-#include "mongoc-init.h"
-#include "mongoc-openssl-private.h"
-#include "mongoc-socket.h"
-#include "mongoc-ssl.h"
-#include "mongoc-stream-tls-openssl-private.h"
-#include "mongoc-thread-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-util-private.h"
+#include <mongoc/mongoc-http-private.h>
+#include <mongoc/mongoc-init.h>
+#include <mongoc/mongoc-openssl-private.h>
+#include <mongoc/mongoc-socket.h>
+#include <mongoc/mongoc-ssl.h>
+#include <mongoc/mongoc-stream-tls-openssl-private.h>
+#include <mongoc/mongoc-thread-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-util-private.h>
 
 #ifdef MONGOC_ENABLE_OCSP_OPENSSL
-#include "mongoc-ocsp-cache-private.h"
+#include <mongoc/mongoc-ocsp-cache-private.h>
 #endif
 
 #ifdef _WIN32
@@ -1002,6 +1002,12 @@ _mongoc_openssl_ctx_new (mongoc_ssl_opt_t *opt)
       return NULL;
    }
 
+   if (opt->weak_cert_validation) {
+      SSL_CTX_set_verify (ctx, SSL_VERIFY_NONE, NULL);
+   } else {
+      SSL_CTX_set_verify (ctx, SSL_VERIFY_PEER, NULL);
+   }
+
    return ctx;
 }
 
