@@ -14,11 +14,12 @@
  * limitations under the License.
  */
 
-#include "mongoc-opts-helpers-private.h"
-#include "mongoc-client-session-private.h"
-#include "mongoc-write-concern-private.h"
-#include "mongoc-util-private.h"
-#include "mongoc-read-concern-private.h"
+#include <mongoc/mongoc-opts-helpers-private.h>
+#include <mongoc/mongoc-client-session-private.h>
+#include <mongoc/mongoc-write-concern-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <mongoc/mongoc-read-concern-private.h>
+#include <common-cmp-private.h>
 
 #define BSON_ERR(...)                                                                    \
    do {                                                                                  \
@@ -57,7 +58,7 @@ void
 _mongoc_timestamp_append (mongoc_timestamp_t *timestamp, bson_t *bson, char *key)
 {
    const size_t len = strlen (key);
-   BSON_ASSERT (bson_in_range_unsigned (int, len));
+   BSON_ASSERT (mcommon_in_range_unsigned (int, len));
    bson_append_timestamp (bson, key, (int) len, timestamp->timestamp, timestamp->increment);
 }
 
