@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_SOCKET_PRIVATE_H
 #define MONGOC_SOCKET_PRIVATE_H
 
-#include "mongoc/mongoc-socket.h"
+#include <mongoc/mongoc-socket.h>
 
 BSON_BEGIN_DECLS
 
@@ -35,9 +35,7 @@ struct _mongoc_socket_t {
 };
 
 mongoc_socket_t *
-mongoc_socket_accept_ex (mongoc_socket_t *sock,
-                         int64_t expire_at,
-                         uint16_t *port);
+mongoc_socket_accept_ex (mongoc_socket_t *sock, int64_t expire_at, uint16_t *port);
 
 BSON_END_DECLS
 
