@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,13 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_STREAM_GRIDFS_DOWNLOAD_PRIVATE_H
 #define MONGOC_STREAM_GRIDFS_DOWNLOAD_PRIVATE_H
 
-#include "mongoc-stream.h"
-#include "mongoc-gridfs-bucket-file-private.h"
+#include <mongoc/mongoc-stream.h>
+#include <mongoc/mongoc-gridfs-bucket-file-private.h>
 
 typedef struct {
    mongoc_stream_t stream;
