@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,12 +15,12 @@
  */
 
 
-#include "mongoc/mongoc-stream-private.h"
-#include "mongoc/mongoc-stream-socket.h"
-#include "mongoc/mongoc-trace-private.h"
-#include "mongoc/mongoc-socket-private.h"
-#include "mongoc/mongoc-errno-private.h"
-#include "mongoc/mongoc-counters-private.h"
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-stream-socket.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-socket-private.h>
+#include <mongoc/mongoc-errno-private.h>
+#include <mongoc/mongoc-counters-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "stream"
@@ -99,11 +99,8 @@ _mongoc_stream_socket_failed (mongoc_stream_t *stream)
 
 
 static int
-_mongoc_stream_socket_setsockopt (mongoc_stream_t *stream,
-                                  int level,
-                                  int optname,
-                                  void *optval,
-                                  mongoc_socklen_t optlen)
+_mongoc_stream_socket_setsockopt (
+   mongoc_stream_t *stream, int level, int optname, void *optval, mongoc_socklen_t optlen)
 {
    mongoc_stream_socket_t *ss = (mongoc_stream_socket_t *) stream;
    int ret;
@@ -123,16 +120,14 @@ static int
 _mongoc_stream_socket_flush (mongoc_stream_t *stream)
 {
    ENTRY;
+   BSON_UNUSED (stream);
    RETURN (0);
 }
 
 
 static ssize_t
-_mongoc_stream_socket_readv (mongoc_stream_t *stream,
-                             mongoc_iovec_t *iov,
-                             size_t iovcnt,
-                             size_t min_bytes,
-                             int32_t timeout_msec)
+_mongoc_stream_socket_readv (
+   mongoc_stream_t *stream, mongoc_iovec_t *iov, size_t iovcnt, size_t min_bytes, int32_t timeout_msec)
 {
    mongoc_stream_socket_t *ss = (mongoc_stream_socket_t *) stream;
    int64_t expire_at;
@@ -154,8 +149,7 @@ _mongoc_stream_socket_readv (mongoc_stream_t *stream,
     */
 
    for (;;) {
-      nread = mongoc_socket_recv (
-         ss->sock, iov[cur].iov_base, iov[cur].iov_len, 0, expire_at);
+      nread = mongoc_socket_recv (ss->sock, iov[cur].iov_base, iov[cur].iov_len, 0, expire_at);
 
       if (nread <= 0) {
          if (ret >= (ssize_t) min_bytes) {
@@ -191,10 +185,7 @@ _mongoc_stream_socket_readv (mongoc_stream_t *stream,
 
 
 static ssize_t
-_mongoc_stream_socket_writev (mongoc_stream_t *stream,
-                              mongoc_iovec_t *iov,
-                              size_t iovcnt,
-                              int32_t timeout_msec)
+_mongoc_stream_socket_writev (mongoc_stream_t *stream, mongoc_iovec_t *iov, size_t iovcnt, int32_t timeout_msec)
 {
    mongoc_stream_socket_t *ss = (mongoc_stream_socket_t *) stream;
    int64_t expire_at;
@@ -214,12 +205,9 @@ _mongoc_stream_socket_writev (mongoc_stream_t *stream,
 
 
 static ssize_t
-_mongoc_stream_socket_poll (mongoc_stream_poll_t *streams,
-                            size_t nstreams,
-                            int32_t timeout_msec)
+_mongoc_stream_socket_poll (mongoc_stream_poll_t *streams, size_t nstreams, int32_t timeout_msec)
 
 {
-   int i;
    ssize_t ret = -1;
    mongoc_socket_poll_t *sds;
    mongoc_stream_socket_t *ss;
@@ -228,7 +216,7 @@ _mongoc_stream_socket_poll (mongoc_stream_poll_t *streams,
 
    sds = (mongoc_socket_poll_t *) bson_malloc (sizeof (*sds) * nstreams);
 
-   for (i = 0; i < nstreams; i++) {
+   for (size_t i = 0u; i < nstreams; i++) {
       ss = (mongoc_stream_socket_t *) streams[i].stream;
 
       if (!ss->sock) {
@@ -242,7 +230,7 @@ _mongoc_stream_socket_poll (mongoc_stream_poll_t *streams,
    ret = mongoc_socket_poll (sds, nstreams, timeout_msec);
 
    if (ret > 0) {
-      for (i = 0; i < nstreams; i++) {
+      for (size_t i = 0u; i < nstreams; i++) {
          streams[i].revents = sds[i].revents;
       }
    }
