@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-config.h"
+#include <mongoc/mongoc-config.h>
 
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
 
@@ -23,16 +23,17 @@
 #include <errno.h>
 #include <string.h>
 
-#include "mongoc-counters-private.h"
-#include "mongoc-errno-private.h"
-#include "mongoc-stream-tls.h"
-#include "mongoc-stream-private.h"
-#include "mongoc-stream-tls-private.h"
-#include "mongoc-stream-tls-openssl-bio-private.h"
-#include "mongoc-stream-tls-openssl-private.h"
-#include "mongoc-openssl-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-log.h"
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-errno-private.h>
+#include <mongoc/mongoc-stream-tls.h>
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-stream-tls-private.h>
+#include <mongoc/mongoc-stream-tls-openssl-bio-private.h>
+#include <mongoc/mongoc-stream-tls-openssl-private.h>
+#include <mongoc/mongoc-openssl-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-log.h>
+#include <common-cmp-private.h>
 
 
 #undef MONGOC_LOG_DOMAIN
@@ -214,7 +215,7 @@ mongoc_stream_tls_openssl_bio_read (BIO *b, char *buf, int len)
       RETURN (-1);
    }
 
-   if (BSON_UNLIKELY (!bson_in_range_signed (int32_t, tls->timeout_msec))) {
+   if (BSON_UNLIKELY (!mcommon_in_range_signed (int32_t, tls->timeout_msec))) {
       // CDRIVER-4589
       MONGOC_ERROR ("timeout_msec value %" PRId64 " exceeds supported 32-bit range", tls->timeout_msec);
       return -1;
@@ -234,7 +235,7 @@ mongoc_stream_tls_openssl_bio_read (BIO *b, char *buf, int len)
       BIO_set_retry_read (openssl->bio);
    }
 
-   BSON_ASSERT (bson_in_range_signed (int, ret));
+   BSON_ASSERT (mcommon_in_range_signed (int, ret));
 
    RETURN ((int) ret);
 }
@@ -282,7 +283,7 @@ mongoc_stream_tls_openssl_bio_write (BIO *b, const char *buf, int len)
    iov.iov_base = (void *) buf;
    iov.iov_len = (size_t) len;
 
-   if (BSON_UNLIKELY (!bson_in_range_signed (int32_t, tls->timeout_msec))) {
+   if (BSON_UNLIKELY (!mcommon_in_range_signed (int32_t, tls->timeout_msec))) {
       // CDRIVER-4589
       MONGOC_ERROR ("timeout_msec value %" PRId64 " exceeds supported 32-bit range", tls->timeout_msec);
       RETURN (-1);
@@ -307,7 +308,7 @@ mongoc_stream_tls_openssl_bio_write (BIO *b, const char *buf, int len)
       BIO_set_retry_write (openssl->bio);
    }
 
-   BSON_ASSERT (bson_in_range_signed (int, ret));
+   BSON_ASSERT (mcommon_in_range_signed (int, ret));
 
    RETURN ((int) ret);
 }
