@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,11 @@
  * limitations under the License.
  */
 
+#include <mongoc/mongoc-prelude.h>
+
 #ifndef MONGOC_STREAM_TLS_SECURE_TRANSPORT_PRIVATE_H
 #define MONGOC_STREAM_TLS_SECURE_TRANSPORT_PRIVATE_H
 
-#if !defined(MONGOC_INSIDE) && !defined(MONGOC_COMPILATION)
-#error "Only <mongoc/mongoc.h> can be included directly."
-#endif
-
 #ifdef MONGOC_ENABLE_SSL_SECURE_TRANSPORT
 #include <bson/bson.h>
 
