@@ -217,7 +217,7 @@ bool mc_FLE2RangeFindDriverSpec_parse(mc_FLE2RangeFindDriverSpec_t *spec,
     // {$and: [{$gt: ["$age", 5]}, {$lt:["$age", 50]}]}
     // Or `in` may be a Match Expression with this form:
     // {$and: [{age: {$gt: 5}}, {age: {$lt: 50}} ]}
-    bson_iter_t and, array;
+    bson_iter_t and = {0}, array = {0};
     bool ok = false;
 
     if (!parse_and(in, &and, status)) {
@@ -264,7 +264,7 @@ bool mc_FLE2RangeFindDriverSpec_parse(mc_FLE2RangeFindDriverSpec_t *spec,
             }
         }
 
-        operator_value_t op;
+        operator_value_t op = {0};
         switch (arg_type) {
         case AGGREGATE_EXPRESSION:
             if (!parse_aggregate_expression(in, &doc, &op, status)) {
@@ -364,12 +364,10 @@ bool mc_makeRangeFindPlaceholder(mc_makeRangeFindPlaceholder_args_t *args,
         TRY(bson_append_iter(edgesInfo, "indexMin", -1, &args->indexMin));
         TRY(bson_append_iter(edgesInfo, "indexMax", -1, &args->indexMax));
         if (args->precision.set) {
-            BSON_ASSERT(args->precision.value <= INT32_MAX);
-            TRY(BSON_APPEND_INT32(edgesInfo, "precision", (int32_t)args->precision.value));
+            TRY(BSON_APPEND_INT32(edgesInfo, "precision", args->precision.value));
         }
         if (args->trimFactor.set) {
-            BSON_ASSERT(args->trimFactor.value <= INT32_MAX);
-            TRY(BSON_APPEND_INT32(edgesInfo, "trimFactor", (int32_t)args->trimFactor.value));
+            TRY(BSON_APPEND_INT32(edgesInfo, "trimFactor", args->trimFactor.value));
         }
         TRY(BSON_APPEND_DOCUMENT(v, "edgesInfo", edgesInfo));
     }
